[pve-devel] r5887 - qemu-server/pve2/PVE

svn-commits at proxmox.com svn-commits at proxmox.com
Mon May 2 12:00:41 CEST 2011


Author: dietmar
Date: 2011-05-02 12:00:41 +0200 (Mon, 02 May 2011)
New Revision: 5887

Modified:
   qemu-server/pve2/PVE/QemuServer.pm
Log:
add win7 os type


Modified: qemu-server/pve2/PVE/QemuServer.pm
===================================================================
--- qemu-server/pve2/PVE/QemuServer.pm	2011-05-02 07:22:40 UTC (rev 5886)
+++ qemu-server/pve2/PVE/QemuServer.pm	2011-05-02 10:00:41 UTC (rev 5887)
@@ -194,7 +194,7 @@
     ostype => {
 	optional => 1,
 	type => 'string',
-        enum => [qw(other wxp w2k w2k3 w2k8 wvista l24 l26)],
+        enum => [qw(other wxp w2k w2k3 w2k8 wvista win7 l24 l26)],
 	description => <<EODESC,
 Used to enable special optimization/features for specific
 operating systems:
@@ -205,11 +205,12 @@
 w2k3   => Microsoft Windows 2003
 w2k8   => Microsoft Windows 2008
 wvista => Microsoft Windows Vista
+win7   => Microsoft Windows 7
 l24    => Linux 2.4 Kernel
 l26    => Linux 2.6 Kernel
 
-other|l24|l26             ... no special behaviour
-wxp|w2k|w2k3|w2k8|wvista  ... use --localtime switch
+other|l24|l26                  ... no special behaviour
+wxp|w2k|w2k3|w2k8|wvista|win7  ... use --localtime switch
 EODESC
     },
     boot => {
@@ -559,6 +560,7 @@
 	w2k3 =>, 'Windows 2003',
 	w2k8 => 'Windows 2008',
 	wvista => 'Windows Vista',
+	win7 => 'Windows 7',
 	l24 => 'Linux 2.4',
 	l26 => 'Linux 2.6',
     }; 
@@ -1875,7 +1877,7 @@
     my $nokvm = defined ($conf->{kvm}) && $conf->{kvm} == 0 ? 1 : 0;
 
     if (my $ost = $conf->{ostype}) {
 	# other, wxp, w2k, w2k3, w2k8, wvista, l24, l26
 
 	if ($ost =~ m/^w/) { # windows
 	    push @$cmd, '-localtime' if !defined ($conf->{localtime});
@@ -1875,7 +1877,7 @@
 
     if (my $ost = $conf->{ostype}) {
-	# other, wxp, w2k, w2k3, w2k8, wvista, l24, l26
+	# other, wxp, w2k, w2k3, w2k8, wvista, win7, l24, l26
 
 	if ($ost =~ m/^w/) { # windows




More information about the pve-devel mailing list